@@ -1,5 +1,5 @@
 package MooX::Role::POE::Emitter;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Moo::Role;
 
@@ -114,14 +114,14 @@ sub _start_emitter {
     object_states => [
 
       $self => {
-        '_start'           => '_p_emitter_start',
-        '_stop'            => '_p_emitter_stop',
-        'shutdown_emitter' => '_p_shutdown_emitter',
+        '_start'           => '__emitter_start',
+        '_stop'            => '__emitter_stop',
+        'shutdown_emitter' => '__shutdown_emitter',
 
-        'register'    => '_p_emitter_register',
-        'subscribe'   => '_p_emitter_register',
-        'unregister'  => '_p_emitter_unregister',
-        'unsubscribe' => '_p_emitter_unregister',
+        'register'    => '__emitter_register',
+        'subscribe'   => '__emitter_register',
+        'unregister'  => '__emitter_unregister',
+        'unsubscribe' => '__emitter_unregister',
 
         'emit'        => '__emitter_notify',
 
@@ -302,8 +302,8 @@ sub __decr_ses_refc {
 
 sub __get_ses_refc {
   my ($self, $sess_id) = @_;
-  $self->__emitter_reg_sessions->{$sess_id}->{refc}
-    if exists $self->__emitter_reg_sessions->{$sess_id}
+  return unless exists $self->__emitter_reg_sessions->{$sess_id};
+  $self->__emitter_reg_sessions->{$sess_id}->{refc} || 0
 }
 
 sub __reg_ses_id {
@@ -359,7 +359,7 @@ sub __emitter_notify {
   $kernel->call( $_[SESSION], $meth, @args )
     if delete $sessions{ $_[SESSION]->ID };
 
-  ## Dispatched to N_$event after Sessions have been notified:
+  ## Dispatched to N_$event after our Session has been notified:
   my $eat = $self->_pluggable_process( 'NOTIFY', $event, \@args );
 
   unless ($eat == EAT_ALL) {
@@ -373,7 +373,7 @@ sub __emitter_notify {
     if $event eq 'shutdown';
 }
 
-sub _p_emitter_start {
+sub __emitter_start {
   ## _start handler
   my ($kernel, $self)    = @_[KERNEL, OBJECT];
   my ($session, $sender) = @_[SESSION, SENDER];
@@ -433,7 +433,7 @@ sub _emitter_sigdie {
   $kernel->sig_handled;
 }
 
-sub _p_emitter_stop {
+sub __emitter_stop {
   ## _stop handler
   my ($kernel, $self) = @_[KERNEL, OBJECT];
 
@@ -449,7 +449,7 @@ sub _shutdown_emitter {
   1
 }
 
-sub _p_shutdown_emitter {
+sub __shutdown_emitter {
   my ($kernel, $self) = @_[KERNEL, OBJECT];
 
   $kernel->alarm_remove_all;
@@ -466,7 +466,7 @@ sub _p_shutdown_emitter {
 
 
 ## Handlers for listener sessions.
-sub _p_emitter_register {
+sub __emitter_register {
   my ($kernel, $self, $sender) = @_[KERNEL, OBJECT, SENDER];
   my @events = @_[ARG0 .. $#_];
 
@@ -484,8 +484,8 @@ sub _p_emitter_register {
     ## Make sure registered session hangs around
     ##  (until _unregister or shutdown)
     $kernel->refcount_increment( $s_id, 'Emitter running' )
-      if not $self->__get_ses_refc($s_id)
-      and $s_id ne $self->session_id ;
+      unless $s_id eq $self->session_id
+      or $self->__get_ses_refc($s_id);
 
     $self->__incr_ses_refc( $s_id );
   }
@@ -493,7 +493,7 @@ sub _p_emitter_register {
   $kernel->post( $s_id, $self->event_prefix . "registered", $self )
 }
 
-sub _p_emitter_unregister {
+sub __emitter_unregister {
   my ($kernel, $self, $sender) = @_[KERNEL, OBJECT, SENDER];
   my @events = @_[ARG0 .. $#_];
 
@@ -545,7 +545,6 @@ MooX::Role::POE::Emitter - Pluggable POE event emitter role for cows
 
   sub spawn {
     my ($self, %args) = @_;
-    $args{lc $_} = delete $args{$_} for keys %args;
 
     $self->set_object_states(
       [
@@ -674,8 +673,8 @@ Set via B<set_object_states>
 
 =head4 session_id
 
-B<session_id> is our emitter's L<POE::Session> ID.
-
+B<session_id> is our emitter's L<POE::Session> ID, set when our Session is 
+started via L</"_start_emitter">.
 
 =head3 _start_emitter
 
@@ -683,7 +682,6 @@ B<_start_emitter()> should be called on our object to spawn the actual
 L<POE::Session>. It takes no arguments and should be called after the 
 object has been configured.
 
-
 =head2 Listening sessions
 
 =head3 Session event subscription
@@ -698,8 +696,9 @@ normal POE event dispatch by sending a C<subscribe>:
 
 Listening sessions are consumers; they cannot modify event arguments in 
 any meaningful way, and will receive arguments as-normal (in @_[ARG0 .. 
-$#_] like any other POE state). Plugins operate differently -- see 
-L<MooX::Role::Pluggable> for details on plugins and argument modification.
+$#_] like any other POE state). Plugins operate differently and receive 
+references to arguments that can be modified -- see 
+L<MooX::Role::Pluggable> for details.
 
 =head3 Session event unregistration
 
@@ -715,8 +714,17 @@ as above:
 
 =head3 Events delivered to listeners
 
-Events delivered to subscribed listener sessions are prefixed with 
-L</event_prefix>. See L</"Session event subscription"> and L</"emit">
+Events are delivered to subscribed listener sessions as normal POE events, 
+with the configured L</event_prefix> prepended and arguments available via 
+C< @_[ARG0 .. $#_] > as normal.
+
+  sub emitted_my_event {
+    my ($kernel, $self) = @_[KERNEL, OBJECT];
+    my @args = @_[ARG0 .. $#_];
+    # . . .
+  }
+
+See L</"Session event subscription"> and L</"emit">
 
 =head3 Events delivered to this session
 
@@ -742,10 +750,16 @@ class:
 =head2 EAT values
 
 L<MooX::Role::Pluggable> uses C<EAT_*> constants to indicate event 
-lifetime. If a plugin in the pipeline returns EAT_CLIENT or EAT_ALL, events 
-are not dispatched to subscribed listening sessions.
+lifetime.
 
-See L<MooX::Role::Pluggable> for details.
+If a plugin in the pipeline returns EAT_CLIENT or EAT_ALL, events 
+are not dispatched to subscribed listening sessions; a dispatched NOTIFY 
+event goes to your emitter's Session if it is subscribed to receive it, 
+then to the plugin pipeline, and finally to other subscribed listener 
+Sessions B<unless> a plugin returned EAT_CLIENT or EAT_ALL.
+
+See L</"emit"> for more on dispatch behavior and event lifetime. See 
+L<MooX::Role::Pluggable> for details regarding plugins.
 
 =head3 NOTIFY events
 
@@ -753,7 +767,7 @@ B<NOTIFY> events are intended to be dispatched asynchronously to our own
 session, any loaded plugins in the pipeline, and subscribed listening 
 sessions, respectively.
 
-See L</emit> for complete details.
+See L</emit>.
 
 =head3 PROCESS events
 
@@ -779,8 +793,11 @@ sessions (with L</event_prefix> prepended):
   ## With default event_prefix:
   $self->emit( 'my_event', @args )
   #  -> Dispatched to own session as 'emitted_my_event'
-  #  --> Dispatched to plugin pipeline as 'N_my_event'
-  #  ---> Dispatched to registered sessions as 'emitted_my_event'
+  #  -> Dispatched to plugin pipeline as 'N_my_event'
+  #  -> Dispatched to registered sessions as 'emitted_my_event'
+  #     *unless* a plugin returned EAT_CLIENT or EAT_ALL
+
+See L</"Receiving events">, L</"EAT values">
 
 =head3 emit_now
 
@@ -799,15 +816,17 @@ immediately; these are B<not> dispatched to listening sessions.
 See L<MooX::Role::Pluggable> for details on pluggable 
 event dispatch.
 
+=head2 Methods
 
-=head2 Session dispatch
+These methods provide easy proxy mechanisms for issuing POE events and 
+managing timers within the context of the emitter's L<POE::Session>.
 
 =head3 yield
 
   $self->yield( $poe_event, @args );
 
 Provides an interface to L<POE::Kernel>'s yield() method, dispatching POE 
-events  within the context of the emitter's session.
+events within the context of the emitter's session.
 
 =head3 call
 
@@ -840,5 +859,7 @@ Derived from L<POE::Component::Syndicator>-0.06 by BINGOS, HINRIK,
 APOCAL et al. That will probably do you for non-Moo(se) use cases; I 
 needed something cow-like that worked with L<MooX::Role::Pluggable>.
 
+Licensed under the same terms as perl5
+
 =cut
 
